'use strict';Object.defineProperty(exports,'__esModule',{value:true});var envStore=require('./envStore.cjs'),core=require('@babel/core');const extractEnvironmentVariables = (path, codeAsString) => {
    path.node.arguments[1].properties.forEach((environmentProperty) => {
        const keyValueAsString = codeAsString.substring(environmentProperty.start, environmentProperty.end);
        const finalObj = {};
        finalObj.required = !keyValueAsString.includes('default');
        if (keyValueAsString.includes('devDefault')) {
            finalObj.devRequired = false;
        }
        envStore.default.addFunction([
            {
                [keyValueAsString.substring(0, keyValueAsString.indexOf(':'))]: finalObj,
            },
        ]);
    });
};
/**
 * Expects an AST tree with start of the node
 * Extract the object part of the string and convert to
 * `
 *  {
 *    NODE_ENV: { required: true },
 *    ENV1: { required: false }, // if `default` exist
 *    ENV2: { devRequired: false }, // if `devDefault` exist
 * }
 * `
 */
let ranForPublicConfig = false;
const currentKeys = [];
function envLogger() {
    return {
        visitor: {
            CallExpression(path, state) {
                if (path.node.callee?.name === 'cleanEnv' ||
                    (path.node.callee?.object?.name === 'envalid' && path.node.callee?.property?.name === 'cleanEnv')) {
                    extractEnvironmentVariables(path, state.file.code);
                }
                if (path.node.callee?.type === 'SequenceExpression') {
                    let hasCleanEnvString = false;
                    path.node.callee.expressions.forEach((seqExp) => {
                        if (seqExp?.object?.name === 'cleanEnv') {
                            hasCleanEnvString = true;
                        }
                        if (seqExp?.property?.name === 'cleanEnv') {
                            hasCleanEnvString = true;
                        }
                    });
                    if (hasCleanEnvString) {
                        extractEnvironmentVariables(path, state.file.code);
                    }
                }
            },
            VariableDeclarator(path) {
                if (path.node?.id?.name === 'publicEnv') {
                    ranForPublicConfig = true;
                    if (path.node?.init.elements) {
                        path.node?.init?.elements.forEach((stringNode) => {
                            if (stringNode?.value) {
                                currentKeys.push(stringNode?.value);
                            }
                        });
                    }
                    else if (path.node?.init?.properties) {
                        path.node?.init?.properties.forEach((publicEnvproperty) => {
                            if (publicEnvproperty?.key?.name) {
                                currentKeys.push(publicEnvproperty?.key?.name);
                            }
                        });
                    }
                    else if (path.node?.init?.value) {
                        if (path.node.init.value) {
                            currentKeys.push(path.node.init.value);
                        }
                    }
                }
            },
        },
        post() {
            if (ranForPublicConfig) {
                envStore.default.currentKeys = currentKeys;
            }
        },
    };
}
const sourceToAst = (source) => {
    core.transformSync(source, {
        // Need to pass a filename when manually calling babel
        filename: 'file.ts',
        presets: ['@babel/preset-env', '@babel/preset-typescript'],
        plugins: [envLogger],
    });
};exports.default=envLogger;exports.sourceToAst=sourceToAst;//# sourceMappingURL=envLogger.cjs.map
